@@ -18,6 +18,8 @@ N_("Matthew is a vegan and a Computer Science student who loves FOSS.")
 N_("I'm cooking from time to time and started to add recipes here.")
 N_("Artist, Computer Scientist, Translator.")
 N_("I love cooking and learning.")
+N_("Another designer who loves to cook")
+N_("GNOME contributor and cook")
 N_("Artist, Computer Scientist, Traveller.")
 N_("I love cooking. :)")
 N_("Aviation, making stuff, in Finland.")
