@@ -1,5 +1,169 @@
 #if 0
 
+N_("Burjji")
+N_("Burjji is one of those treats that you can have at any time.  It is usually served at roadside restaurants or stalls along highways but can also be seen in the cities as well.")
+N_("This is basically indian style scrambled eggs with veggies and chillis.  There are a lot of variations.")
+N_("In a saucepan, melt butter till full melted")
+N_("Add the cumin seeds, and toast until brown")
+N_("Add onions and green chillis")
+N_("Cook until onions are soft and slightly browned")
+N_("Add finely chopped tomato and cook for 10 minutes under medium heat until tomato is well cooked and incorporated with the onions")
+N_("Add salt and pepper to taste")
+N_("Add the optional ingredients and cook for another 5 minutes")
+N_("In a mixing bowl, whisk the eggs until fully combined and then add the milk, add the salt and pepper")
+N_("Add the chopped cilantro and mix well")
+N_("Pour the egg mixture onto the sauce pan and stir gently incorporating the vegetables with the eggs")
+N_("Cook till just set with barely any liquid")
+N_("Serve!")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Shaksuka")
+N_("It's a dish from Israel; it's typically made with tomatoes but other vegetables can be used instead.")
+N_("This is Henry's version of it.")
+N_("Chop everything except tomatoes in tiny pieces. ")
+N_("Take the seeds off the tomatoes and chop them as well. ")
+N_("Heat oil on a pan. ")
+N_("Put tomatoes and peppers on the pan and let them boil. ")
+N_("Add the rest of ingredients except eggs. Cook it for 2 or 4 minutes. ")
+N_("Make little wells in the vegs mix and break the eggs inside. The idea is that eggs won't spread and disappear. ")
+N_("Cook until eggs are done. ")
+N_("Serve in the same pan it was cooked accompanied by crackers or pita bread.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Beef Pho")
+N_("Pho (or phở) is a brothy Vietnamese noodle dish usually made from beef or chicken, but it's really really worth the effort to make. While some of the ingredients may seem daunting or unusual, they're really not and they're easy to find in your local Asian market.")
+N_("This first step isn't necessary, but it adds dimension to your broth: place both the ginger and the onion (whole and unpeeled) on a very hot grill/bbq. Cook and turn often until the outsides of both are completely black and blistering. Place in cold water to quickly cool before you remove the peel and most of the blackened bits. ")
+N_("Pour your beef stock into a large stock pot and add all the whole herbs & spices plus the fish sauce, rock sugar and the whole onion and ginger. Bring to a rolling boil, cover and reduce the heat and let simmer for an hour or so.")
+N_("Cook the rice vermicelli noodles as directed on the package and set aside.  Peel, halve and thinly slice the red onion. ")
+N_("Next, very thinly slice the beef (partially freezing it beforehand will make it much easier to slice) –it's important to slice the raw meat very thin so it will cook in hot broth upon serving. Finally, chop up the pre-cooked beef.")
+N_("Strain the broth through a fine mesh colander, return to heat and bring to a boil.  ")
+N_("Place some of the cooked rice noodles and sliced beef and onion into bowls for serving. Pour the hot broth over it this –it should cook the meat very quickly.")
+N_("Arrange the garnishes and sauces out for your diners to pick and choose for themselves. Varying which garnishes you choose will change the overall flavour of the soup, feel free to change it up on your second serving.")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Broth Ingredients")
+N_("Serving Ingredients")
+N_("Serving Ingredients")
+N_("Serving Ingredients")
+N_("Serving Ingredients")
+N_("Garnishes")
+N_("Garnishes")
+N_("Garnishes")
+N_("Garnishes")
+N_("Garnishes")
+N_("Garnishes")
+N_("Garnishes")
+N_("Garnishes")
+N_("Garnishes")
+N_("Pad Priew Wan Goong")
+N_("This is a summer, tone-down version of the original Thai dish.")
+N_("If you change shrimp for cheese or soja protein it will be vegetarian or vegan.")
+N_("1. Combine the seasoning ingredients, stir together, then set aside. ")
+N_("2. Pat the shrimp dry with paper towels.")
+N_("3. Heat a wok with a bit of oil and garlic. Stir-fry with the shrimp. ")
+N_("4. Prepare the salad. Add the shrimp with its garlic. Mix well. ")
+N_("5. Serve garnished with the seasoning and, if you like, some plain rice (cold or slightly warm).")
+N_("** You can ignore the vinegar or use lemon juice instead.")
+N_("** Fish sauce can be swapped with Worcestershire or similar strong flavoured sauce.")
+N_("** If you want it hotter, you can add Tabasco.")
+N_("Salad")
+N_("Salad")
+N_("Salad")
+N_("Salad")
+N_("Salad")
+N_("Salad")
+N_("Seasoning")
+N_("Seasoning")
+N_("Seasoning")
+N_("Seasoning")
+N_("Seasoning")
+N_("Seasoning")
+N_("Seasoning")
+N_("Seasoning")
+N_("Seasoning")
+N_("Homemade Mayonnaise")
+N_("Classic recipe. ")
+N_("You can prepare it and store it in the fridge for later use.")
+N_("1. Combine the egg yolks, salt, and pepper in a bowl. Carefully add the mustard, lemon juice and vinegar.  ")
+N_("2. Then, mixing constantly, add the oil to the previous mix and keep whipping vigorously until the mixture emulsify and becomes rather creamy (like in the picture).")
+N_("3. For best results, refrigerate for 1 hour before using.")
+N_("** Vinegar is optional. You can do it with lemon juice only.")
+N_("** With Honey Mustard tastes even better and gives it a personal touch.")
+N_("** If you want, you can tone down a bit the cholesterol load by adding some avocado (palta) purée. This is easy to do. Just empty a ripe avocado with a spoon and smash the stuff with a fork.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Arroz amarillo")
+N_("Base for many Spanish dishes like Paella and Arroz con mariscos.")
+N_("1. Prepare the saffron with the rice.  Chop bell pepper, onions and garlic, keeping them apart.")
+N_("2. Warm the oil in a large skillet over medium heat. Add bell pepper and sauté until just softened, then stir in the onions and sauté until softened. Stir in the rice and garlic, and sauté until the rice is well-coated and starting to turn opaque, stirring constantly to prevent sticking, about 2 minutes.  Don't forget the saffron!")
+N_("3. Stir in broth, tomato paste, salt, and pepper. Bring to a simmer then cover, reduce heat to low, and simmer until the liquid has evaporated (listen for when the rice stops bubbling). Try it and if it tastes and feels about right, remove it from heat and set aside, covered and undisturbed until is done. ")
+N_("-------------------------------- ")
+N_("** Pour water little by little, if water is not enough, add more.  It's always better too little than too much as getting rid of water will throw spices and flavour as well. ")
+N_("** If you use the wine/broth combo instead of just broth, add the wine first and let it simmer for a couple minutes, stirring often, before adding the broth and proceeding as directed.")
+N_("---------------------------------")
+N_("Broth substitutes:")
+N_("1 cup of white wine, 1 cup of water.")
+N_("1 cup of white wine, 1 cup of broth.")
+N_("2 cups of water.")
+N_("Remember that parboiled rice needs more time for cooking than normal one.")
+N_("For the Saffron always follow the instructions detailed in the package, whether is powder or strands.")
+N_("Hawaiian Fish Salad")
+N_("Personal version of a Hawaiian salad (with raw fish).")
+N_("1. Chop tuna in chunks and cook it on a skillet with a touch of olive oil, salt & pepper. ")
+N_("2. Cook the potatoes and leave them aside to cool down.")
+N_("3. Meanwhile, combine the seasoning ingredients, and leave it to rest for a while. ")
+N_("4. Meanwhile potatoes and fish get cooled and the seasoning rests, chop the vegetables. ")
+N_("5. Cut the potatoes in chunks or slices. ")
+N_("6. Mix all together, season and serve.")
+N_("** You can use the canned filets but it doesn't taste as good as using fresh fish.")
+N_("** You can add other vegetables at will, like mushrooms or lettuce.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
 N_("Bourbon Pork Loin")
 N_("This is a modified version of a recipe found on a website.")
 N_("1. Combine the spice rub ingredients, and rub all over the pork. Let sit at room temperature as you preheat your oven to 110ºC.")
