@@ -20,132 +20,115 @@
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
+#include <math.h>
 
 #include "gr-number.h"
 #include "gr-utils.h"
 
-static int
-gcd (int m, int n)
+
+typedef struct {
+        int num;
+        int denom;
+        double value;
+} Approximation;
+
+/* These are all candidates with 'nice' denominators
+ * (i.e. 2, 3, 4, 5, 6, 8, 10, 12, 15, 16), sorted
+ * by size.
+ */
+static Approximation approx[] = {
+  {  0,  1, 0.0/1.0 },
+  {  1, 16, 1.0/16.0 },
+  {  1, 15, 1.0/15.0 },
+  {  1, 12, 1.0/12.0 },
+  {  1, 10, 1.0/10.0 },
+  {  1,  8, 1.0/8.0 },
+  {  2, 15, 2.0/15.0 },
+  {  1,  6, 1.0/6.0 },
+  {  3, 16, 3.0/16.0 },
+  {  1,  5, 1.0/5.0 },
+  {  1,  4, 1.0/4.0 },
+  {  4, 15, 4.0/15.0 },
+  {  3, 10, 3.0/10.0 },
+  {  5, 16, 5.0/16.0 },
+  {  1,  3, 1.0/3.0 },
+  {  3,  8, 3.0/8.0 },
+  {  2,  5, 2.0/5.0 },
+  {  5, 12, 5.0/12.0 },
+  {  7, 16, 7.0/16.0 },
+  {  7, 15, 7.0/15.0 },
+  {  1,  2, 1.0/2.0 },
+  {  8, 15, 8.0/15.0 },
+  {  9, 16, 9.0/16.0 },
+  {  7, 12, 7.0/12.0 },
+  {  3,  5, 3.0/5.0 },
+  {  5,  8, 5.0/8.0 },
+  {  2,  3, 2.0/3.0 },
+  { 11, 16, 11.0/16.0 },
+  {  7, 10, 7.0/10.0 },
+  { 11, 15, 11.0/15.0 },
+  {  3,  4, 3.0/4.0 },
+  {  4,  5, 4.0/5.0 },
+  { 13, 16, 13.0/16.0 },
+  {  5,  6, 5.0/6.0 },
+  { 13, 15, 13.0/15.0 },
+  {  7,  8, 7.0/8.0 },
+  {  9, 10, 9.0/10.0 },
+  { 11, 12, 11.0/12.0 },
+  { 14, 15, 14.0/15.0 },
+  { 15, 16, 15.0/16.0 },
+  {  1,  1, 1.0/1.0 }
+};
+
+static void
+rational_approximation (double  input,
+                        int    *num,
+                        int    *denom)
 {
-        int r;
+        int i;
 
-        if (m == 0 && n == 0)
-                return -1;
-
-        if (m < 0) m = -m;
-        if (n < 0) n = -n;
-
-        while (n) {
-                r = m % n;
-                m = n;
-                n = r;
+        for (i = 0; i < G_N_ELEMENTS (approx); i++) {
+                if (approx[i].value >= input) {
+                        if (i > 0 && input - approx[i - 1].value < approx[i].value - input)
+                                i--;
+                        break;
+                }
         }
-
-        return m;
-}
-
-void
-gr_number_set_fraction (GrNumber *number,
-                        int       num,
-                        int       denom)
-{
-        int g;
-
-        if (denom < 0) {
-                num = -num;
-                denom = -denom;
-        }
-        g = gcd (num, denom);
-        number->fraction = TRUE;
-        number->num = num / g;
-        number->denom = denom / g;
-        number->value = ((double) num) / ((double) denom);
-}
-
-void
-gr_number_set_float (GrNumber *number,
-                     double    value)
-{
-        number->fraction = FALSE;
-        number->num = 0;
-        number->denom = 0;
-        number->value = value;
-}
-
-GrNumber *
-gr_number_new_fraction (int num, int denom)
-{
-        GrNumber *number;
-
-        number = g_new (GrNumber, 1);
-        gr_number_set_fraction (number, num, denom);
-
-        return number;
-}
-
-GrNumber *
-gr_number_new_float (double value)
-{
-        GrNumber *number;
-
-        number = g_new (GrNumber, 1);
-        gr_number_set_float (number, value);
-
-        return number;
-}
-
-void
-gr_number_multiply (GrNumber *a1,
-                    GrNumber *a2,
-                    GrNumber *b)
-{
-        if (a1->fraction && a2->fraction)
-                gr_number_set_fraction (b, a1->num * a2->num, a1->denom * a2->denom);
-        else
-                gr_number_set_float (b, a1->value * a2->value);
-}
-
-void
-gr_number_add (GrNumber *a1,
-               GrNumber *a2,
-               GrNumber *b)
-{
-        if (a1->fraction && a2->fraction)
-                gr_number_set_fraction (b, a1->num * a2->denom + a2->num * a1->denom, a1->denom * a2->denom);
-        else
-                gr_number_set_float (b, a1->value + a2->value);
+        *num = approx[i].num;
+        *denom = approx[i].denom;
 }
 
 typedef struct {
         int num;
         int denom;
         const char *ch;
+        double value;
 } VulgarFraction;
 
+/* a workaround for poor availability of OpenType frak support in our fonts */
 static VulgarFraction fractions[] = {
-        { 1,  4, "¼" },
-        { 1,  2, "½" },
-        { 3,  4, "¾" },
-        { 1,  7, "⅐" },
-        { 1,  9, "⅑" },
-        { 1, 10, "⅒" },
-        { 1,  3, "⅓" },
-        { 2,  3, "⅔" },
-        { 1,  5, "⅕" },
-        { 2,  5, "⅖" },
-        { 3,  5, "⅗" },
-        { 4,  5, "⅘" },
-        { 1,  6, "⅙" },
-        { 5,  6, "⅚" },
-        { 1,  8, "⅛" },
-        { 3,  8, "⅜" },
-        { 5,  8, "⅝" },
-        { 7,  8, "⅞" }
+        { 1,  2, "½", 1.0/2.0 },
+        { 1,  3, "⅓", 1.0/3.0 },
+        { 2,  3, "⅔", 2.0/3.0 },
+        { 1,  4, "¼", 1.0/4.0 },
+        { 3,  4, "¾", 3.0/4.0 },
+        { 1,  5, "⅕", 1.0/5.0 },
+        { 2,  5, "⅖", 2.0/5.0 },
+        { 3,  5, "⅗", 3.0/5.0 },
+        { 4,  5, "⅘", 4.0/5.0 },
+        { 1,  6, "⅙", 1.0/6.0 },
+        { 5,  6, "⅚", 5.0/6.0 },
+        { 1,  7, "⅐", 1.0/7.0 },
+        { 1,  8, "⅛", 1.0/8.0 },
+        { 3,  8, "⅜", 3.0/8.0 },
+        { 5,  8, "⅝", 5.0/8.0 },
+        { 7,  8, "⅞", 7.0/8.0 },
+        { 1,  9, "⅑", 1.0/9.0 },
+        { 1, 10, "⅒", 1.0/10.0 }
 };
 
-/* a workaround for poor availability of OpenType frak support in our fonts */
 static gboolean
-parse_as_vulgar_fraction (GrNumber  *number,
+parse_as_vulgar_fraction (double    *number,
                           char     **input,
                           GError   **error)
 {
@@ -155,9 +138,8 @@ parse_as_vulgar_fraction (GrNumber  *number,
                 const char *vf = fractions[i].ch;
                 if (g_str_has_prefix (*input, vf) &&
                     space_or_nul ((*input)[strlen (vf)])) {
-                        gr_number_set_fraction (number, fractions[i].num, fractions[i].denom);
+                        *number = fractions[i].value;
                         *input += strlen (vf);
-
                         return TRUE;
                 }
         }
@@ -169,15 +151,15 @@ parse_as_vulgar_fraction (GrNumber  *number,
 }
 
 static gboolean
-parse_as_fraction (GrNumber  *number,
+parse_as_fraction (double    *number,
                    char     **input,
                    GError   **error)
 {
         char *orig = *input;
-        guint64 num, denom;
+        gint64 num, denom;
         char *end = NULL;
 
-        num = g_ascii_strtoull (orig, &end, 10);
+        num = g_ascii_strtoll (orig, &end, 10);
         if (end == NULL || end == orig || end[0] != '/') {
                 g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
                              _("Could not parse %s as a fraction"), *input);
@@ -186,30 +168,31 @@ parse_as_fraction (GrNumber  *number,
 
         orig = end + 1;
 
-        denom = g_ascii_strtoull (orig, &end, 10);
+        denom = g_ascii_strtoll (orig, &end, 10);
         if (end != NULL && !space_or_nul (end[0])) {
                 g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
                              _("Could not parse %s as a fraction"), *input);
                 return FALSE;
         }
+        if (denom == 0)
+                denom = 1;
 
         *input = end;
-
-        gr_number_set_fraction (number, (int)num, (int)denom);
+        *number = (double)num / (double)MAX(denom, 1);
 
         return TRUE;
 }
 
 static gboolean
-parse_as_integer (GrNumber  *number,
+parse_as_integer (double    *number,
                   char     **input,
                   gboolean   require_whitespace,
                   GError   **error)
 {
-        guint64 num;
+        gint64 num;
         char *end = NULL;
 
-        num = g_ascii_strtoull (*input, &end, 10);
+        num = g_ascii_strtoll (*input, &end, 10);
         if (end == *input ||
             (require_whitespace && end != NULL && !space_or_nul (end[0]))) {
                 g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
@@ -217,14 +200,13 @@ parse_as_integer (GrNumber  *number,
                return FALSE;
         }
         *input = end;
-
-        gr_number_set_fraction (number, (int)num, 1);
+        *number = (double)num;
 
         return TRUE;
 }
 
 static gboolean
-parse_as_float (GrNumber  *number,
+parse_as_float (double    *number,
                 char     **input,
                 GError   **error)
 {
@@ -240,14 +222,13 @@ parse_as_float (GrNumber  *number,
                 return FALSE;
         }
         *input = end;
-
-        gr_number_set_float (number, value);
+        *number = value;
 
         return TRUE;
 }
 
 gboolean
-gr_number_parse (GrNumber  *number,
+gr_number_parse (double    *number,
                  char     **input,
                  GError   **error)
 {
@@ -264,14 +245,14 @@ gr_number_parse (GrNumber  *number,
         if (parse_as_integer (number, &orig, FALSE, NULL)) {
                 gboolean valid;
                 char *endofint;
-                GrNumber n;
+                double n;
 
                 endofint = orig;
                 valid = skip_whitespace (&orig);
 
                 if (parse_as_vulgar_fraction (&n, &orig, NULL) ||
                     parse_as_fraction (&n, &orig, NULL)) {
-                        gr_number_add (number, &n, number);
+                        *number = *number + n;
                         *input = orig;
                         return TRUE;
                 }
@@ -292,41 +273,64 @@ gr_number_parse (GrNumber  *number,
         return FALSE;
 }
 
+static const char *sup[] = { "⁰", "¹", "²", "³", "⁴", "⁵", "⁶", "⁷", "⁸", "⁹" };
+static const char *sub[] = { "₀", "₁", "₂", "₃", "₄", "₅", "₆", "₇", "₈", "₉" };
+
+static void
+append_digits (GString    *s,
+               const char *digits[],
+               int         n)
+{
+        if (n == 0)
+                return;
+
+        append_digits (s, digits, n / 10);
+        g_string_append (s, digits[n % 10]);
+}
+
 static char *
-format_fraction (int num, int denom)
+format_fraction (int integral,
+                 int num,
+                 int denom)
 {
         int i;
+        GString *s;
+
+        s = g_string_new ("");
+
+        if (integral != 0)
+                g_string_append_printf (s, "%d", integral);
+
+        if (num == 0)
+                goto out;
+
+        if (integral != 0)
+                g_string_append (s, " ");
 
         for (i = 0; i < G_N_ELEMENTS (fractions); i++) {
-                if (fractions[i].num == num && fractions[i].denom == denom)
-                        return g_strdup (fractions[i].ch);
+                if (fractions[i].num == num && fractions[i].denom == denom) {
+                        g_string_append (s, fractions[i].ch);
+                        goto out;
+                }
         }
 
-        return g_strdup_printf ("%d/%d", num, denom);
+        append_digits (s, sup, num);
+        g_string_append (s, "⁄");
+        append_digits (s, sub, denom);
+
+out:
+        return g_string_free (s, FALSE);
 }
 
 char *
-gr_number_format (GrNumber *number)
+gr_number_format (double number)
 {
-        if (number->fraction) {
-                if (number->denom == 1)
-                        return g_strdup_printf ("%d", number->num);
-                else {
-                        int integral;
-                        g_autofree char *fraction = NULL;
+        double integral;
+        int num, denom;
 
-                        if (number->denom == 0)
-                                return g_strdup ("");
+        integral = floor (number);
+        number -= integral;
 
-                        integral = number->num / number->denom;
-                        fraction = format_fraction (number->num % number->denom, number->denom);
-                        if (integral == 0)
-                                return g_strdup_printf ("%s", fraction);
-                        else
-                                return g_strdup_printf ("%d %s", integral, fraction);
-                }
-        }
-        else {
-                return g_strdup_printf ("%g", number->value);
-        }
+        rational_approximation (number, &num, &denom);
+        return format_fraction ((int)integral, num, denom);
 }
