@@ -46,6 +46,7 @@
 #include "gr-account.h"
 #include "gr-utils.h"
 #include "gr-appdata.h"
+#include "gr-settings.h"
 
 
 struct _GrWindow
@@ -75,6 +76,11 @@ struct _GrWindow
         GtkWidget *image_page;
         GtkWidget *cooking_page;
 
+        GtkWidget *sort_by_label;
+        GtkWidget *sort_by_name_button;
+        GtkWidget *sort_by_recency_button;
+        GtkWidget *sort_popover;
+
         GtkWidget *undo_revealer;
         GtkWidget *undo_label;
         GrRecipe  *undo_recipe;
@@ -298,7 +304,7 @@ search_mode_changed (GrWindow *window)
 static void
 switch_to_search (GrWindow *window)
 {
-        configure_window (window, "", "main", "main", "search", "search");
+        configure_window (window, "", "main", "main", "list", "search");
 }
 
 void
@@ -379,12 +385,14 @@ visible_page_changed (GrWindow *window)
                 gr_recipes_page_refresh (GR_RECIPES_PAGE (window->recipes_page));
                 gr_recipes_page_unexpand (GR_RECIPES_PAGE (window->recipes_page));
                 gtk_header_bar_set_title (GTK_HEADER_BAR (window->header), _("Recipes"));
+                gtk_stack_set_visible_child_name (GTK_STACK (window->header_end_stack), "main");
         }
 
         if (strcmp (visible, "cuisines") == 0) {
                 gr_cuisines_page_refresh (GR_CUISINES_PAGE (window->cuisines_page));
                 gr_cuisines_page_unexpand (GR_CUISINES_PAGE (window->cuisines_page));
                 gtk_header_bar_set_title (GTK_HEADER_BAR (window->header), _("Cuisines"));
+                gtk_stack_set_visible_child_name (GTK_STACK (window->header_end_stack), "main");
         }
 }
 
@@ -541,17 +549,6 @@ window_delete_handler (GtkWidget *widget)
         return FALSE;
 }
 
-static void
-hide_or_show_header_end_stack (GObject    *object,
-                               GParamSpec *pspec,
-                               GrWindow   *window)
-{
-        const char *visible;
-
-        visible = gtk_stack_get_visible_child_name (GTK_STACK (window->header_end_stack));
-        gtk_widget_set_visible (window->header_end_stack, strcmp (visible, "list") != 0);
-}
-
 GrWindow *
 gr_window_new (GrApp *app)
 {
@@ -560,7 +557,7 @@ gr_window_new (GrApp *app)
 
 typedef struct {
         GrRecipe *recipe;
-        int serves;
+        double yield;
 } ShoppingListEntry;
 
 static void
@@ -800,7 +797,7 @@ back_to_shopping (GrWindow *window)
 
         for (l = window->shopping_done_list; l; l = l->next) {
                 ShoppingListEntry *entry = l->data;
-                gr_recipe_store_add_to_shopping (store, entry->recipe, entry->serves);
+                gr_recipe_store_add_to_shopping (store, entry->recipe, entry->yield);
         }
         for (i = 0; window->removed_ingredients && window->removed_ingredients[i]; i++) {
                 gr_recipe_store_remove_shopping_ingredient (store, window->removed_ingredients[i]);
@@ -849,7 +846,7 @@ done_shopping (GrWindow *window)
 
                 entry = g_new (ShoppingListEntry, 1);
                 entry->recipe = g_object_ref (recipe);
-                entry->serves = gr_recipe_store_get_shopping_serves (store, recipe);
+                entry->yield = gr_recipe_store_get_shopping_yield (store, recipe);
                 window->shopping_done_list = g_list_append (window->shopping_done_list, entry);
         }
         g_list_free_full (recipes, g_object_unref);
@@ -875,6 +872,37 @@ make_save_sensitive (GrEditPage *edit_page,
                 gtk_widget_set_sensitive (window->save_button,FALSE);
 }
 
+static void
+update_sort_menu (GrWindow *window)
+{
+        switch (g_settings_get_enum (gr_settings_get (), "sort-key")) {
+        case SORT_BY_NAME:
+                g_object_set (window->sort_by_name_button, "active", TRUE, NULL);
+                g_object_set (window->sort_by_recency_button, "active", FALSE, NULL);
+                g_object_set (window->sort_by_label, "label", _("Sorted by Name"), NULL);
+                break;
+        case SORT_BY_RECENCY:
+                g_object_set (window->sort_by_name_button, "active", FALSE, NULL);
+                g_object_set (window->sort_by_recency_button, "active", TRUE, NULL);
+                g_object_set (window->sort_by_label, "label", _("Sorted by Recency"), NULL);
+                break;
+        default:
+                g_assert_not_reached ();
+        }
+}
+
+static void
+sort_clicked (GtkWidget *button,
+              GrWindow  *window)
+{
+        GSettings *settings = gr_settings_get ();
+
+        gtk_popover_popdown (GTK_POPOVER (window->sort_popover));
+        g_settings_set_enum (settings, "sort-key",
+                             button == window->sort_by_name_button ? SORT_BY_NAME : SORT_BY_RECENCY);
+        update_sort_menu (window);
+}
+
 static void
 gr_window_class_init (GrWindowClass *klass)
 {
@@ -913,13 +941,16 @@ gr_window_class_init (GrWindowClass *klass)
         gtk_widget_class_bind_template_child (widget_class, GrWindow, remind_label);
         gtk_widget_class_bind_template_child (widget_class, GrWindow, shopping_added_revealer);
         gtk_widget_class_bind_template_child (widget_class, GrWindow, shopping_done_revealer);
+        gtk_widget_class_bind_template_child (widget_class, GrWindow, sort_by_label);
+        gtk_widget_class_bind_template_child (widget_class, GrWindow, sort_by_name_button);
+        gtk_widget_class_bind_template_child (widget_class, GrWindow, sort_by_recency_button);
+        gtk_widget_class_bind_template_child (widget_class, GrWindow, sort_popover);
 
         gtk_widget_class_bind_template_callback (widget_class, new_recipe);
         gtk_widget_class_bind_template_callback (widget_class, go_back);
         gtk_widget_class_bind_template_callback (widget_class, add_recipe);
         gtk_widget_class_bind_template_callback (widget_class, visible_page_changed);
         gtk_widget_class_bind_template_callback (widget_class, start_cooking);
-        gtk_widget_class_bind_template_callback (widget_class, hide_or_show_header_end_stack);
         gtk_widget_class_bind_template_callback (widget_class, search_changed);
         gtk_widget_class_bind_template_callback (widget_class, stop_search);
         gtk_widget_class_bind_template_callback (widget_class, search_mode_changed);
@@ -939,6 +970,7 @@ gr_window_class_init (GrWindowClass *klass)
         gtk_widget_class_bind_template_callback (widget_class, close_shopping_done);
         gtk_widget_class_bind_template_callback (widget_class, back_to_shopping);
         gtk_widget_class_bind_template_callback (widget_class, make_save_sensitive);
+        gtk_widget_class_bind_template_callback (widget_class, sort_clicked);
 }
 
 static GtkClipboard *
@@ -995,13 +1027,18 @@ gr_window_init (GrWindow *self)
         g_action_map_add_action_entries (G_ACTION_MAP (self),
                                          entries, G_N_ELEMENTS (entries),
                                          self);
+
+        update_sort_menu (self);
 }
 
 void
 gr_window_go_back (GrWindow *window)
 {
-        if (g_queue_is_empty (window->back_entry_stack)) {
-                configure_window (window, _("Recipes"), "main", "main", "search", "recipes");
+        if (gtk_search_bar_get_search_mode (GTK_SEARCH_BAR (window->search_bar))) {
+                gtk_search_bar_set_search_mode (GTK_SEARCH_BAR (window->search_bar), FALSE);
+        }
+        else if (g_queue_is_empty (window->back_entry_stack)) {
+                configure_window (window, _("Recipes"), "main", "main", "main", "recipes");
         }
         else {
                 go_back (window);
@@ -1214,7 +1251,7 @@ gr_window_show_chef (GrWindow *window,
 
         save_back_entry (window);
 
-        gr_list_page_populate_from_chef (GR_LIST_PAGE (window->chef_page), chef);
+        gr_list_page_populate_from_chef (GR_LIST_PAGE (window->chef_page), chef,  FALSE);
         title = g_strdup_printf (_("Chefs: %s"), gr_chef_get_fullname (chef));
         configure_window (window, title, "back", "title", "list", "chef");
 }
@@ -1285,7 +1322,7 @@ do_show_mine (GrChef   *chef,
 
         save_back_entry (window);
 
-        gr_list_page_populate_from_chef (GR_LIST_PAGE (window->chef_page), chef);
+        gr_list_page_populate_from_chef (GR_LIST_PAGE (window->chef_page), chef, TRUE);
         configure_window (window, _("My Recipes"), "back", "title", "list", "chef");
 }
 
@@ -1515,3 +1552,57 @@ gr_window_show_report_issue (GrWindow *window)
 
         gtk_show_uri_on_window (GTK_WINDOW (window), uri, GDK_CURRENT_TIME, NULL);
 }
+
+/* Show the surprise dialog between the first day of GUADEC and
+ * the end of the year, but only once.
+ */
+static gboolean
+should_show_surprise (void)
+{
+        g_autoptr(GDateTime) now = NULL;
+        g_autoptr(GDateTime) start = NULL;
+        g_autoptr(GDateTime) end = NULL;
+
+        if (g_getenv ("SHOW_SURPRISE"))
+                return TRUE;
+
+        if (!g_settings_get_boolean (gr_settings_get (), "show-surprise-dialog"))
+                return FALSE;
+
+        now = g_date_time_new_now_utc ();
+        start = g_date_time_new_utc (2017, 7, 27, 0, 0, 0);
+        end = g_date_time_new_utc (2017, 12, 31, 0, 0, 0);
+
+        if (g_date_time_compare (start, now) < 0 && g_date_time_compare (now, end) < 0)
+                return TRUE;
+
+        return FALSE;
+}
+
+void
+surprise_dialog_closed (GtkWidget *window)
+{
+        g_settings_set_boolean (gr_settings_get (), "show-surprise-dialog", FALSE);
+        gtk_widget_destroy (window);
+}
+
+void
+gr_window_show_surprise (GrWindow *window)
+{
+        g_autoptr(GtkBuilder) builder = NULL;
+        GtkWindow *dialog;
+        GtkWidget *button;
+        GtkWidget *label;
+
+        if (!should_show_surprise ())
+                return;
+
+        builder = gtk_builder_new_from_resource ("/org/gnome/Recipes/recipe-surprise.ui");
+        dialog = GTK_WINDOW (gtk_builder_get_object (builder, "dialog"));
+        label = GTK_WIDGET (gtk_builder_get_object (builder, "label"));
+        button = GTK_WIDGET (gtk_builder_get_object (builder, "close_button"));
+        g_signal_connect_swapped (button, "clicked", G_CALLBACK (surprise_dialog_closed), dialog);
+        gtk_window_set_transient_for (dialog, GTK_WINDOW (window));
+        gr_window_present_dialog (window, dialog);
+        pango_layout_set_spacing (gtk_label_get_layout (GTK_LABEL (label)), - pango_units_from_double (10.0));
+}
